==> aws-android-sdk-transcribe-2.22.5-sources.jar: com/amazonaws/services/transcribe/model/transform/CreateVocabularyFilterRequestMarshaller.java <==
/*
 * Copyright 2010-2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.transcribe.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;

import android.text.TextUtils;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.transcribe.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.AwsJsonWriter;
import com.amazonaws.util.json.JsonUtils;

/**
 * JSON request marshaller for CreateVocabularyFilterRequest
 */
public class CreateVocabularyFilterRequestMarshaller implements
        Marshaller<Request<CreateVocabularyFilterRequest>, CreateVocabularyFilterRequest> {

    public Request<CreateVocabularyFilterRequest> marshall(
            CreateVocabularyFilterRequest createVocabularyFilterRequest) {
        if (createVocabularyFilterRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(CreateVocabularyFilterRequest)");
        }

        Request<CreateVocabularyFilterRequest> request = new DefaultRequest<CreateVocabularyFilterRequest>(
                createVocabularyFilterRequest, "AmazonTranscribe");
        String target = "Transcribe.CreateVocabularyFilter";
        request.addHeader("X-Amz-Target", target);
        request.setHttpMethod(HttpMethodName.POST);

        String uriResourcePath = "/";
        request.setResourcePath(uriResourcePath);
        try {
            StringWriter stringWriter = new StringWriter();
            AwsJsonWriter jsonWriter = JsonUtils.getJsonWriter(stringWriter);
            jsonWriter.beginObject();

            if (createVocabularyFilterRequest.getVocabularyFilterName() != null) {
                String vocabularyFilterName = createVocabularyFilterRequest
                        .getVocabularyFilterName();
                jsonWriter.name("VocabularyFilterName");
                jsonWriter.value(vocabularyFilterName);
            }
            if (createVocabularyFilterRequest.getLanguageCode() != null) {
                String languageCode = createVocabularyFilterRequest.getLanguageCode();
                jsonWriter.name("LanguageCode");
                jsonWriter.value(languageCode);
            }
            if (createVocabularyFilterRequest.getWords() != null) {
                java.util.List<String> words = createVocabularyFilterRequest.getWords();
                jsonWriter.name("Words");
                jsonWriter.beginArray();
                for (String wordsItem : words) {
                    if (wordsItem != null) {
                        jsonWriter.value(wordsItem);
                    }
                }
                jsonWriter.endArray();
            }
            if (createVocabularyFilterRequest.getVocabularyFilterFileUri() != null) {
                String vocabularyFilterFileUri = createVocabularyFilterRequest
                        .getVocabularyFilterFileUri();
                jsonWriter.name("VocabularyFilterFileUri");
                jsonWriter.value(vocabularyFilterFileUri);
            }

            jsonWriter.endObject();
            jsonWriter.close();
            String snippet = stringWriter.toString();
            byte[] content = snippet.getBytes(UTF8);
            request.setContent(new StringInputStream(snippet));
            request.addHeader("Content-Length", Integer.toString(content.length));
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
        if (!request.getHeaders().containsKey("Content-Type")) {
            request.addHeader("Content-Type", "application/x-amz-json-1.1");
        }

        return request;
    }
}

==> aws-android-sdk-transcribe-2.55.0-sources.jar: com/amazonaws/services/transcribe/model/transform/CreateVocabularyFilterRequestMarshaller.java <==
/*
 * Copyright 2010-2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.transcribe.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;

import android.text.TextUtils;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.transcribe.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.DateUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.AwsJsonWriter;
import com.amazonaws.util.json.JsonUtils;

/**
 * JSON request marshaller for CreateVocabularyFilterRequest
 */
public class CreateVocabularyFilterRequestMarshaller implements
        Marshaller<Request<CreateVocabularyFilterRequest>, CreateVocabularyFilterRequest> {

    public Request<CreateVocabularyFilterRequest> marshall(
            CreateVocabularyFilterRequest createVocabularyFilterRequest) {
        if (createVocabularyFilterRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(CreateVocabularyFilterRequest)");
        }

        Request<CreateVocabularyFilterRequest> request = new DefaultRequest<CreateVocabularyFilterRequest>(
                createVocabularyFilterRequest, "AmazonTranscribe");
        String target = "Transcribe.CreateVocabularyFilter";
        request.addHeader("X-Amz-Target", target);
        request.setHttpMethod(HttpMethodName.POST);

        String uriResourcePath = "/";
        request.setResourcePath(uriResourcePath);
        try {
            StringWriter stringWriter = new StringWriter();
            AwsJsonWriter jsonWriter = JsonUtils.getJsonWriter(stringWriter);
            jsonWriter.beginObject();

            if (createVocabularyFilterRequest.getVocabularyFilterName() != null) {
                String vocabularyFilterName = createVocabularyFilterRequest
                        .getVocabularyFilterName();
                jsonWriter.name("VocabularyFilterName");
                jsonWriter.value(vocabularyFilterName);
            }
            if (createVocabularyFilterRequest.getLanguageCode() != null) {
                String languageCode = createVocabularyFilterRequest.getLanguageCode();
                jsonWriter.name("LanguageCode");
                jsonWriter.value(languageCode);
            }
            if (createVocabularyFilterRequest.getWords() != null) {
                java.util.List<String> words = createVocabularyFilterRequest.getWords();
                jsonWriter.name("Words");
                jsonWriter.beginArray();
                for (String wordsItem : words) {
                    if (wordsItem != null) {
                        jsonWriter.value(wordsItem);
                    }
                }
                jsonWriter.endArray();
            }
            if (createVocabularyFilterRequest.getVocabularyFilterFileUri() != null) {
                String vocabularyFilterFileUri = createVocabularyFilterRequest
                        .getVocabularyFilterFileUri();
                jsonWriter.name("VocabularyFilterFileUri");
                jsonWriter.value(vocabularyFilterFileUri);
            }
            if (createVocabularyFilterRequest.getTags() != null) {
                java.util.List<Tag> tags = createVocabularyFilterRequest.getTags();
                jsonWriter.name("Tags");
                jsonWriter.beginArray();
                for (Tag tagsItem : tags) {
                    if (tagsItem != null) {
                        TagJsonMarshaller.getInstance().marshall(tagsItem, jsonWriter);
                    }
                }
                jsonWriter.endArray();
            }

            jsonWriter.endObject();
            jsonWriter.close();
            String snippet = stringWriter.toString();
            byte[] content = snippet.getBytes(UTF8);
            request.setContent(new StringInputStream(snippet));
            request.addHeader("Content-Length", Integer.toString(content.length));
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
        if (!request.getHeaders().containsKey("Content-Type")) {
            request.addHeader("Content-Type", "application/x-amz-json-1.1");
        }

        return request;
    }
}
